@@ -29,6 +29,7 @@
 #include <QString>
 
 #include <KGlobalSettings>
+#include <KLocale>
 #include <KStandardDirs>
 #include <KUrl>
 
@@ -153,6 +154,7 @@ static const char conf_iconFont[] = "IconFont";
 // interface statistics
 static const char conf_activateStatistics[] = "ActivateStatistics";
 static const char conf_calendar[] = "Calendar";
+static const char conf_calendarSystem[] = "CalendarSystem";
 static const char conf_statsRules[] = "StatsRules";
 static const char conf_warnRules[] = "WarnRules";
 
@@ -233,11 +235,7 @@ enum ToolTipEnums
     ENCRYPTION       = 0x00800000
 };
 
-#ifdef HAVE_KSTATUSNOTIFIERITEM
 static const int defaultTip = STATUS | IP_ADDRESS | RX_BYTES | TX_BYTES | ESSID | LINK_QUALITY | DOWNLOAD_SPEED | UPLOAD_SPEED | ENCRYPTION;
-#else
-static const int defaultTip = INTERFACE | STATUS | IP_ADDRESS | RX_BYTES | TX_BYTES | ESSID | LINK_QUALITY | DOWNLOAD_SPEED | UPLOAD_SPEED | ENCRYPTION;
-#endif
 
 struct KNemoTheme
 {
@@ -418,7 +416,8 @@ struct InterfaceSettings
         trafficThreshold( 0 ),
         hideWhenUnavailable( false ),
         hideWhenDisconnected( false ),
-        activateStatistics( false )
+        activateStatistics( false ),
+        calendarSystem( KLocale::QDateCalendar )
     {}
 
     QString iconTheme;
@@ -441,7 +440,7 @@ struct InterfaceSettings
     bool activateStatistics;
     QList<StatsRule> statsRules;
     QList<WarnRule> warnRules;
-    QString calendar;
+    KLocale::CalendarSystem calendarSystem;
     QString alias;
     QList<InterfaceCommand> commands;
 };
